pub enum BiometricsStatus {
Available,
UnlockNeeded,
HardwareUnavailable,
NotEnabled,
}Expand description
The current biometric capability state for a specific user on this client.
Variants
Available
Biometrics is available and can be used immediately.
UnlockNeeded
Biometrics is supported, but user interaction is required before unlock can proceed.
Biometrics hardware or platform support is unavailable.
NotEnabled
Biometrics is supported but not enabled for this user.